adjust_library_size: Adjust count matrix by library size

View source: R/adjust_library_size.R

adjust_library_sizeR Documentation

Adjust count matrix by library size

Description

Simple tool for adjusting raw count matrix by total library size. Library size is calculated as column sums and columns are scaled to the median total library size.

Usage

adjust_library_size(x)

Arguments

x

Read count matrix with genes in rows and samples in columns.

Value

Matrix of adjusted read counts


cellGeometry documentation built on April 20, 2026, 1:06 a.m.