| comp_heatmap | R Documentation |
Plots a heatmap of the compensation matrix for cell subclasses using ComplexHeatmap.
comp_heatmap(
x,
cell_table = NULL,
text = NULL,
cutoff = 0.2,
fontsize = 8,
subset = NULL,
...
)
x |
object of class 'deconv' or a matrix of compensation values. |
cell_table |
optional grouping vector to separate the heatmap rows and columns into groups. |
text |
Logical whether to show values whose absolute value > |
cutoff |
Absolute threshold for showing values. |
fontsize |
Numeric value for font size for cell values when
|
subset |
Character vector of groups to be subsetted. |
... |
optional arguments passed to |
No return value. Draws a ComplexHeatmap.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.