confint.deconv: Confidence Intervals for Deconvolution Models

View source: R/rstudent.R

confint.deconvR Documentation

Confidence Intervals for Deconvolution Models

Description

Computes confidence intervals for fitted deconvolution models.

Usage

## S3 method for class 'deconv'
confint(object, parm, level = 0.95, ..., type = "var.e")

Arguments

object

a fitted 'deconv' class model object.

parm

for compatibility with S3 method. Not used.

level

the confidence level required.

...

additional arguments for S3 compatibility.

type

specifies standard error method, see se().

Details

The default "var.e" method for calculating standard error (SE) is recommended. Other SE methods are most reliable with bulk data with low noise, and when fitted compensation values are close to 1 and ridge parameter lambda is close to 0. As compensation values deviate away from 1 or as lambda increases, CI calculated based on OLS/HC0-3 SE inflate and are progressively less reliable.

Value

List containing 2 matrices with lower and upper confidence intervals.

See Also

se()


cellGeometry documentation built on April 20, 2026, 1:06 a.m.