diagnose: Diagnostics for cellMarker signatures

View source: R/diagnose.R

diagnoseR Documentation

Diagnostics for cellMarker signatures

Description

Diagnostic tool which prints information for identifying cell subclasses or groups with weak signatures.

Usage

diagnose(object, group = NULL, angle_cutoff = 30, weak = 2)

Arguments

object

A 'cellMarkers' or 'deconv' class object.

group

Character vector to focus on cell subclasses within a particular group or groups.

angle_cutoff

Angle in degrees below which cell cluster vectors are considered to overlap too much. Range 0-90. See cos_similarity().

weak

Number of 1st ranked genes for each cell cluster at which/below its gene set is considered weak.

Value

No return value. Prints information about the cellMarkers signature showing cells subclasses with weak signatures and diagnostic information including which cell subclasses each problematic signature spills into.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.