fix_group: Fix cellMarkers signature with no cell groups

View source: R/mergeMarkers.R

fix_groupR Documentation

Fix cellMarkers signature with no cell groups

Description

This function is designed to fix cellMarkers objects which were not created with a cellgroup vector and therefore have no cell grouping categories. This can cause issues during merging of cellMarkers objects.

Usage

fix_group(mk, lab)

Arguments

mk

A 'cellMarkers' class object.

lab

Character value to label the overarching group.

Value

A 'cellMarkers' class list object in which the elements cell_table and groupmeans have been updated.

See Also

mergeMarkers()


cellGeometry documentation built on April 20, 2026, 1:06 a.m.