max_similarity: Maximum similarity between cell types

View source: R/cos_similarity.R

max_similarityR Documentation

Maximum similarity between cell types

Description

Computes maximum similarity between cell types based on the gene signature matrix.

Usage

max_similarity(x, ...)

Arguments

x

Either a matrix or a 'cellMarkers' class or 'deconv' class object.

...

Optional arguments passed to cos_similarity().

Value

A vector of similarity results.

See Also

diagnose() which outputs a more comprehensive pairwise comparison of similarity between cell subclasses.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.