| mergeMarkers | R Documentation |
Takes 2 cellMarkers signatures, merges them and recalculates optimal gene signatures.
mergeMarkers(
mk1,
mk2,
remove_subclass = NULL,
remove_group = NULL,
transform = c("qq", "linear.qq", "scale", "none"),
scale = 1,
...
)
mk1 |
The reference 'cellMarkers' class object. |
mk2 |
A 'cellMarkers' class object containing cell signatures to merge
into |
remove_subclass |
Optional character vector of subclasses to remove when merging. |
remove_group |
Optional character vector of cell groups to remove when merging. |
transform |
Either "qq" which applies |
scale |
Numeric value determining the scaling factor for |
... |
Optional arguments and settings passed to |
A list object of S3 class 'cellMarkers'. See cellMarkers() for
details. If transform = "qq" then an additional element qqmerge is
returned containing the quantile mapping function between the 2 datasets.
cellMarkers() updateMarkers() quantile_map()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.