| metric_set | R Documentation |
Calculates Pearson r-squared, R-squared and RMSE comparing subclasses in each
column of obs with matching columns in deconvoluted pred. Samples are in
rows. For use if ground truth is available, e.g. simulated pseudo-bulk
RNA-Seq data.
metric_set(obs, pred)
obs |
Observed matrix of cell amounts with subclasses in columns and samples in rows. |
pred |
Predicted (deconvoluted) matrix of cell amounts with rows and
columns matching |
Pearson r-squared ranges from 0 to 1. R-squared, calculated as 1 - rss/tss, ranges from -Inf to 1.
Matrix containing Pearson r-squared, R-squared and RMSE values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.