plot.qqmap: Quantile-quantile plot

View source: R/quantile_map.R

plot.qqmapR Documentation

Quantile-quantile plot

Description

Produces a QQ plot showing the conversion function from the first dataset to the second.

Usage

## S3 method for class 'qqmap'
plot(x, points = TRUE, ...)

Arguments

x

A 'qqmap' class object created by quantile_map().

points

Logical whether to show quantile points.

...

Optional plotting parameters passed to plot().

Value

No return value. Produces a QQ plot using base graphics with a red line showing the conversion function.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.