plot_biasvar: Plot bias-variance decomposition

View source: R/tune_deconv.R

plot_biasvarR Documentation

Plot bias-variance decomposition

Description

Produces a ggplot2 plot of total error (MSE) against bias and variance based on results generated by tune_deconv(). Primarily useful for examining the effect of altering compensation or lambda.

Usage

plot_biasvar(result, subclass = 1, xvar = colnames(result)[1])

Arguments

result

Dataframe of tuning results generated by tune_deconv().

subclass

Character value specifying which cell subclass to plot, or numeric selecting the subclass by factor level.

xvar

Character value specifying column in result to vary along the x axis.

Value

ggplot2 line plot.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.