| plot_cv | R Documentation |
Plots the cross-validation curve, and upper and lower standard error curves as a function of the ridge parameter lambda.
plot_cv(fit, ...)
fit |
Object of class 'deconv' |
... |
Optional arguments passed to |
No return value. Plots the lambda CV curve using base graphics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.