plot_set: Scatter plots to compare deconvoluted subclasses

View source: R/simulate_bulk.R

plot_setR Documentation

Scatter plots to compare deconvoluted subclasses

Description

Produces a set of scatter plots using base graphics to compare actual cell counts against deconvoluted cell counts from bulk (or pseudo-bulk) RNA-Seq for each cell subclass. Mainly for use if ground truth is available, e.g. for simulated pseudo-bulk RNA-Seq data.

Usage

plot_set(
  obs,
  pred,
  mfrow = NULL,
  show_zero = FALSE,
  show_identity = FALSE,
  cols = NULL,
  colour = "blue",
  title = "",
  cex.title = 1,
  ...
)

Arguments

obs

Observed matrix of cell amounts with subclasses in columns and samples in rows.

pred

Predicted (deconvoluted) matrix of cell amounts with rows and columns matching obs. Alternatively a 'deconv' class fitted model can be supplied and its ⁠$subclass$output⁠ cell counts element will be used.

mfrow

Optional vector of length 2 for organising plot layout. See par().

show_zero

Logical whether to force plot to include the origin.

show_identity

Logical whether to show the identity line.

cols

Optional vector of column indices to plot to show either a subset of columns or change the order in which columns are plotted. NA skips a plot space to introduce a gap between plots.

colour

Colour for the regression lines.

title

Title for page of plots.

cex.title

Font size for title.

...

Optional arguments passed to plot().

Value

No return value. Produces scatter plots using base graphics.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.