| quantile_map | R Documentation |
Quantile mapping to combine two scRNA-Seq datasets based on mapping either the distribution of mean log2+1 gene expression in cell clusters to the distribution of the 2nd dataset, or mapping the quantiles of one matrix of gene expression (with genes in rows) to another.
quantile_map(
x,
y,
n = 10000,
remove_noncoding = TRUE,
remove_zeros = FALSE,
smooth = "loess",
span = 0.15,
knots = c(0.25, 0.75, 0.85, 0.95, 0.97, 0.99, 0.999),
respace = FALSE,
silent = FALSE
)
x |
scRNA-Seq data whose distribution is to be mapped onto |
y |
Reference scRNA-Seq data: either a matrix of gene expression on
log2+1 scale, or a 'cellMarkers' class object, in which case the
|
n |
Number of quantiles to split |
remove_noncoding |
Logical, whether to remove noncoding. This is a basic filter which looks at the gene names (rownames) in both matrices and removes genes containing "-" which are usually antisense or mitochondrial genes, or "." which are either pseudogenes or ribosomal genes. |
remove_zeros |
Logical, whether to remove zeros from both datasets. This shifts the quantile relationships. |
smooth |
Either "loess" or "lowess" which apply |
span |
controls the degree of smoothing in |
knots |
Vector of quantile points for knots for fitting natural splines. |
respace |
Logical whether to respace quantile points so their x axis density is more even. Can help spline fitting. |
silent |
Logical whether to suppress messages. |
The conversion uses the function approxfun() which uses interpolation. It
is not designed to perform stepwise (exact) quantile transformation of every
individual datapoint.
A list object of class 'qqmap' containing:
quantiles |
Dataframe containing matching quantiles of |
map |
A function of form |
approxfun()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.