View source: R/cos_similarity.R
| rank_angle | R Documentation |
Converts a cosine similarity matrix to angular distance. Then orders the
elements in increasing angle. Elements below angle_cutoff are returned in a
dataframe.
rank_angle(x, angle_cutoff = 45)
x |
a cosine similarity matrix generated by |
angle_cutoff |
Cutoff angle in degrees below which to subset the dataframe. |
a dataframe of rows and columns as factors and the angle between
that row and column extracted from the cosine similarity matrix. Row and
column location are stored as factors so that they can be converted back to
coordinates in the similarity matrix easily using as.integer().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.