| reduceNoise | R Documentation |
Simple filter for removing noise in single-cell data.
reduceNoise(cellmat, noisefilter = 2, noisefraction = 0.25)
cellmat |
Matrix of log2 mean gene expression in rows with cell types in columns. |
noisefilter |
Sets an upper bound for |
noisefraction |
Numeric value. Maximum mean log2 gene expression across
cell types is calculated and values in celltypes below this fraction are
set to 0. Set in conjunction with |
Filtered mean gene expression matrix with genes in rows and cell types in columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.