residuals.deconv: Extract Deconvolution Residuals

View source: R/rstudent.R

residuals.deconvR Documentation

Extract Deconvolution Residuals

Description

Extracts residuals from a deconvolution model. As the model uses a reduced signature gene set for deconvolution, in order to extract residuals for all genes, these need to recalculated by supplying the bulk count matrix test.

Usage

## S3 method for class 'deconv'
residuals(object, ..., type = c("raw", "weight"), test = NULL)

Arguments

object

a 'deconv' class object

...

retained for class compatibility

type

Specifies type of residuals, either raw or weighted. Ignored if test is specified.

test

bulk gene expression matrix assumed to be in raw counts

Value

Matrix of residuals.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.