se: Standard errors of deconvoluted cell counts

View source: R/rstudent.R

seR Documentation

Standard errors of deconvoluted cell counts

Description

Extracts standard errors of deconvoluted cell counts based on the row variance of weighted residuals.

Usage

se(model, type = c("var.e", "OLS", "OLS2", "HC0", "HC2", "HC3"))

Arguments

model

a 'deconv' class object

type

specifies standard error method. Default is "var.e", which we recommend as being the most accurate. The alternative options include OLS (ordinary least squares) and several heteroscedasticity-consistent methods, HC0, HC2 and HC3.

Value

with type = "var.e", a vector of standard errors of cell counts for each cell subclass. For all other options, a matrix of SE for every bulk sample and every cell subclass.

See Also

deconvolute()


cellGeometry documentation built on April 20, 2026, 1:06 a.m.