View source: R/spillover_heatmap.R
| spillover_heatmap | R Documentation |
Produces a heatmap from a 'cellMarkers' or 'deconv' class object showing estimated amount of spillover between cell subclasses. The amount that each cell subclass's overall vector spillovers (projects) into other cell subclasses' vectors is shown in each row. Thus the column gives an estimate of how much the most influential (specific) genes for a cell subclass are expressed in other cells.
spillover_heatmap(
x,
text = NULL,
cutoff = 0.5,
fontsize = 8,
subset = NULL,
...
)
x |
Either a 'cellMarkers' or 'deconv' class object or a spillover matrix. |
text |
Logical whether to show values of cells where spillover >
|
cutoff |
Threshold for showing values. |
fontsize |
Numeric value for font size for cell values when
|
subset |
Character vector of groups to be subsetted. |
... |
Optional arguments passed to |
No return value. Draws a heatmap using ComplexHeatmap.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.