summary.tune_deconv: Summarising deconvolution tuning

View source: R/tune_deconv.R

summary.tune_deconvR Documentation

Summarising deconvolution tuning

Description

summary method for class 'tune_deconv'.

Usage

## S3 method for class 'tune_deconv'
summary(
  object,
  metric = attr(object, "metric"),
  method = attr(object, "method"),
  ...
)

Arguments

object

dataframe of class 'tune_deconv'.

metric

Specifies tuning metric to choose optimal tune: either "RMSE", "Rsq", "pearson" or "resvar" (residual variance of bulk gene expression).

method

Either "top" or "overall". Determines how best parameter values are chosen. With "top" the single top configuration is chosen. With "overall", the average effect of varying each parameter is calculated using the mean R-squared across all variations of other parameters. This can give a more stable choice of final tuning.

...

further arguments passed to other methods.

Value

If method = "top" prints the row representing the best tuning of parameters (maximum mean R squared, averaged across subclasses). For method = "overall", the average effect of varying each parameter is calculated by mean R-squared across the rest of the grid and the best value for each parameter is printed. Invisibly returns a dataframe of mean metric values (Pearson r^2, R^2, RMSE) averaged over subclasses.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.