violin_plot: Cell subclass violin plot

View source: R/stack_plot.R

violin_plotR Documentation

Cell subclass violin plot

Description

Produces violin plots using ggplot2 showing amounts of cell subclasses in deconvoluted bulk samples.

Usage

violin_plot(x, percent = FALSE, order_cols = c("none", "increase", "decrease"))

Arguments

x

matrix of deconvolution results with samples in rows and cell subclasses or groups in columns. If a 'deconv' class object is supplied the deconvolution values for the cell subclasses are extracted and plotted.

percent

Logical whether to scale the matrix rows as percentage.

order_cols

Character value specifying with cell types are ordered by mean abundance.

Value

A ggplot2 plotting object.


cellGeometry documentation built on April 20, 2026, 1:06 a.m.