View source: R/adjust_library_size.R
| adjust_library_size | R Documentation |
Simple tool for adjusting raw count matrix by total library size. Library size is calculated as column sums and columns are scaled to the median total library size.
adjust_library_size(x)
x |
Read count matrix with genes in rows and samples in columns. |
Matrix of adjusted read counts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.