| confint.deconv | R Documentation |
Computes confidence intervals for fitted deconvolution models.
## S3 method for class 'deconv'
confint(object, parm, level = 0.95, ..., type = "var.e")
object |
a fitted 'deconv' class model object. |
parm |
for compatibility with S3 method. Not used. |
level |
the confidence level required. |
... |
additional arguments for S3 compatibility. |
type |
specifies standard error method, see |
The default "var.e" method for calculating standard error (SE) is recommended. Other SE methods are most reliable with bulk data with low noise, and when fitted compensation values are close to 1 and ridge parameter lambda is close to 0. As compensation values deviate away from 1 or as lambda increases, CI calculated based on OLS/HC0-3 SE inflate and are progressively less reliable.
List containing 2 matrices with lower and upper confidence intervals.
se()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.