| diagnose | R Documentation |
Diagnostic tool which prints information for identifying cell subclasses or groups with weak signatures.
diagnose(object, group = NULL, angle_cutoff = 30, weak = 2)
object |
A 'cellMarkers' or 'deconv' class object. |
group |
Character vector to focus on cell subclasses within a particular group or groups. |
angle_cutoff |
Angle in degrees below which cell cluster vectors are
considered to overlap too much. Range 0-90. See |
weak |
Number of 1st ranked genes for each cell cluster at which/below its gene set is considered weak. |
No return value. Prints information about the cellMarkers signature showing cells subclasses with weak signatures and diagnostic information including which cell subclasses each problematic signature spills into.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.