| plot.qqmap | R Documentation |
Produces a QQ plot showing the conversion function from the first dataset to the second.
## S3 method for class 'qqmap'
plot(x, points = TRUE, ...)
x |
A 'qqmap' class object created by |
points |
Logical whether to show quantile points. |
... |
Optional plotting parameters passed to |
No return value. Produces a QQ plot using base graphics with a red line showing the conversion function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.