| plot_comp | R Documentation |
Plots the effect of varying compensation from 0 to 1 for each cell subclass,
examining the minimum subclass output result following a call to
deconvolute(). For this function to work, the argument check_comp must be
set to TRUE during the call to deconvolute().
plot_comp(x, overlay = TRUE, type = c("counts", "percent"), mfrow = NULL, ...)
plot_path(
x,
subclass = 1L,
sample = NULL,
type = c("counts", "percent"),
add_points = FALSE,
labs = TRUE,
...
)
x |
An object of class 'deconv' generated by |
overlay |
Logical whether to overlay compensation curves onto a single plot. If FALSE, multiple plots (one per subclass) are generated on one or more pages. |
type |
Either "counts" or "percent", to specify whether deconvoluted cell counts or cell percentages are shown. |
mfrow |
Optional vector of length 2 for organising plot layout. See
|
... |
Optional graphical arguments passed to |
subclass |
Either an index number or character value specifying which cell subclass to plot. |
sample |
Either an index number or character value specifying which
sample to plot. Both |
add_points |
Logical whether to add points showing the final cell count
values. Not available if |
labs |
Either logical, whether to show labels for each line. Or a vector of label names for each line. |
No return value. plot_comp() plots the effect of varying
compensation on the minimum subclass output for every cell subclass.
plot_path() plots the coefficient paths for either each bulk sample for the
subclass specified by subclass, or all subclasses for a single sample
specified by sample.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.