| plot_pred | R Documentation |
Produces a single scatter plot using base graphics to compare actual cell counts against deconvoluted cell counts from bulk (or pseudo-bulk) RNA-Seq Cell subclasses are shown in different colours. Designed for use if ground truth is available, e.g. for simulated pseudo-bulk RNA-Seq data.
plot_pred(
obs,
pred,
mk = NULL,
scheme = NULL,
ellipse = NULL,
labels = TRUE,
main = ""
)
obs |
Observed matrix of cell amounts with subclasses in columns and samples in rows. |
pred |
Predicted (deconvoluted) matrix of cell amounts with rows and
columns matching |
mk |
Optional matching cellMarkers object. This is used for its
|
scheme |
Vector of colours, one for each cell subclass. |
ellipse |
Either a single number for the number of ellipses to plot, in which case ellipses are shown for cell subclasses with the lowest R^2; or a character vector of cell subclasses to be outlined with ellipses. Requires the ggforce package to be installed. |
labels |
Logical whether to add labels to ellipses. |
main |
Title to add to plot. |
A ggplot2 scatter plot. An overall R^2 (coefficient of determination) comparing all observed and predicted results is shown.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.