View source: R/simulate_bulk.R
| plot_set | R Documentation |
Produces a set of scatter plots using base graphics to compare actual cell counts against deconvoluted cell counts from bulk (or pseudo-bulk) RNA-Seq for each cell subclass. Mainly for use if ground truth is available, e.g. for simulated pseudo-bulk RNA-Seq data.
plot_set(
obs,
pred,
mfrow = NULL,
show_zero = FALSE,
show_identity = FALSE,
cols = NULL,
colour = "blue",
title = "",
cex.title = 1,
...
)
obs |
Observed matrix of cell amounts with subclasses in columns and samples in rows. |
pred |
Predicted (deconvoluted) matrix of cell amounts with rows and
columns matching |
mfrow |
Optional vector of length 2 for organising plot layout. See
|
show_zero |
Logical whether to force plot to include the origin. |
show_identity |
Logical whether to show the identity line. |
cols |
Optional vector of column indices to plot to show either a subset
of columns or change the order in which columns are plotted. |
colour |
Colour for the regression lines. |
title |
Title for page of plots. |
cex.title |
Font size for title. |
... |
Optional arguments passed to |
No return value. Produces scatter plots using base graphics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.