| residuals.deconv | R Documentation |
Extracts residuals from a deconvolution model. As the model uses a reduced
signature gene set for deconvolution, in order to extract residuals for all
genes, these need to recalculated by supplying the bulk count matrix test.
## S3 method for class 'deconv'
residuals(object, ..., type = c("raw", "weight"), test = NULL)
object |
a 'deconv' class object |
... |
retained for class compatibility |
type |
Specifies type of residuals, either raw or weighted. Ignored if
|
test |
bulk gene expression matrix assumed to be in raw counts |
Matrix of residuals.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.