| violin_plot | R Documentation |
Produces violin plots using ggplot2 showing amounts of cell subclasses in deconvoluted bulk samples.
violin_plot(x, percent = FALSE, order_cols = c("none", "increase", "decrease"))
x |
matrix of deconvolution results with samples in rows and cell subclasses or groups in columns. If a 'deconv' class object is supplied the deconvolution values for the cell subclasses are extracted and plotted. |
percent |
Logical whether to scale the matrix rows as percentage. |
order_cols |
Character value specifying with cell types are ordered by mean abundance. |
A ggplot2 plotting object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.